"""Smoke tests for src/kindex/notify.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_notify():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.notify")
    assert mod is not None

def test_get_channel_is_callable():
    """Function get_channel exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.notify")
    fn = getattr(mod, "get_channel", None)
    assert fn is not None, "'get_channel' not found in kindex.notify"
    assert callable(fn)

def test_dispatch_is_callable():
    """Function dispatch exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.notify")
    fn = getattr(mod, "dispatch", None)
    assert fn is not None, "'dispatch' not found in kindex.notify"
    assert callable(fn)

def test_get_idle_seconds_is_callable():
    """Function get_idle_seconds exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.notify")
    fn = getattr(mod, "get_idle_seconds", None)
    assert fn is not None, "'get_idle_seconds' not found in kindex.notify"
    assert callable(fn)

def test_is_user_idle_is_callable():
    """Function is_user_idle exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.notify")
    fn = getattr(mod, "is_user_idle", None)
    assert fn is not None, "'is_user_idle' not found in kindex.notify"
    assert callable(fn)
