"""Smoke tests for src/kindex/adapters/files.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_adapters_files():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.adapters.files")
    assert mod is not None

def test_sha256_file_is_callable():
    """Function sha256_file exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.files")
    fn = getattr(mod, "sha256_file", None)
    assert fn is not None, "'sha256_file' not found in kindex.adapters.files"
    assert callable(fn)

def test_scan_registered_files_is_callable():
    """Function scan_registered_files exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.files")
    fn = getattr(mod, "scan_registered_files", None)
    assert fn is not None, "'scan_registered_files' not found in kindex.adapters.files"
    assert callable(fn)

def test_ingest_directory_is_callable():
    """Function ingest_directory exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.files")
    fn = getattr(mod, "ingest_directory", None)
    assert fn is not None, "'ingest_directory' not found in kindex.adapters.files"
    assert callable(fn)
