"""Smoke tests for src/kindex/setup.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_setup():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    assert mod is not None

def test_install_claude_hooks_is_callable():
    """Function install_claude_hooks exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    fn = getattr(mod, "install_claude_hooks", None)
    assert fn is not None, "'install_claude_hooks' not found in kindex.setup"
    assert callable(fn)

def test_install_launchd_is_callable():
    """Function install_launchd exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    fn = getattr(mod, "install_launchd", None)
    assert fn is not None, "'install_launchd' not found in kindex.setup"
    assert callable(fn)

def test_reload_launchd_is_callable():
    """Function reload_launchd exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    fn = getattr(mod, "reload_launchd", None)
    assert fn is not None, "'reload_launchd' not found in kindex.setup"
    assert callable(fn)

def test_uninstall_launchd_is_callable():
    """Function uninstall_launchd exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    fn = getattr(mod, "uninstall_launchd", None)
    assert fn is not None, "'uninstall_launchd' not found in kindex.setup"
    assert callable(fn)

def test_install_crontab_is_callable():
    """Function install_crontab exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    fn = getattr(mod, "install_crontab", None)
    assert fn is not None, "'install_crontab' not found in kindex.setup"
    assert callable(fn)

def test_install_reminder_daemon_is_callable():
    """Function install_reminder_daemon exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.setup")
    fn = getattr(mod, "install_reminder_daemon", None)
    assert fn is not None, "'install_reminder_daemon' not found in kindex.setup"
    assert callable(fn)
