"""Smoke tests for src/kindex/vault.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_vault():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.vault")
    assert mod is not None

def test_parse_frontmatter_is_callable():
    """Function parse_frontmatter exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.vault")
    fn = getattr(mod, "parse_frontmatter", None)
    assert fn is not None, "'parse_frontmatter' not found in kindex.vault"
    assert callable(fn)

def test_serialize_frontmatter_is_callable():
    """Function serialize_frontmatter exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.vault")
    fn = getattr(mod, "serialize_frontmatter", None)
    assert fn is not None, "'serialize_frontmatter' not found in kindex.vault"
    assert callable(fn)
