"""Smoke tests for src/kindex/adapters/pipeline.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_adapters_pipeline():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.adapters.pipeline")
    assert mod is not None

def test_run_adapter_is_callable():
    """Function run_adapter exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.pipeline")
    fn = getattr(mod, "run_adapter", None)
    assert fn is not None, "'run_adapter' not found in kindex.adapters.pipeline"
    assert callable(fn)

def test_run_all_is_callable():
    """Function run_all exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.pipeline")
    fn = getattr(mod, "run_all", None)
    assert fn is not None, "'run_all' not found in kindex.adapters.pipeline"
    assert callable(fn)
