"""Smoke tests for src/kindex/adapters/git_hooks.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_adapters_git_hooks():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.adapters.git_hooks")
    assert mod is not None

def test_install_hooks_is_callable():
    """Function install_hooks exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.git_hooks")
    fn = getattr(mod, "install_hooks", None)
    assert fn is not None, "'install_hooks' not found in kindex.adapters.git_hooks"
    assert callable(fn)

def test_uninstall_hooks_is_callable():
    """Function uninstall_hooks exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.git_hooks")
    fn = getattr(mod, "uninstall_hooks", None)
    assert fn is not None, "'uninstall_hooks' not found in kindex.adapters.git_hooks"
    assert callable(fn)

def test_ingest_recent_commits_is_callable():
    """Function ingest_recent_commits exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.git_hooks")
    fn = getattr(mod, "ingest_recent_commits", None)
    assert fn is not None, "'ingest_recent_commits' not found in kindex.adapters.git_hooks"
    assert callable(fn)
