"""Smoke tests for src/kindex/adapters/linear.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_adapters_linear():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.adapters.linear")
    assert mod is not None

def test_is_linear_available_is_callable():
    """Function is_linear_available exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.linear")
    fn = getattr(mod, "is_linear_available", None)
    assert fn is not None, "'is_linear_available' not found in kindex.adapters.linear"
    assert callable(fn)

def test_ingest_issues_is_callable():
    """Function ingest_issues exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.adapters.linear")
    fn = getattr(mod, "ingest_issues", None)
    assert fn is not None, "'ingest_issues' not found in kindex.adapters.linear"
    assert callable(fn)
