"""Smoke tests for src/kindex/analytics.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_analytics():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.analytics")
    assert mod is not None

def test_find_archive_db_is_callable():
    """Function find_archive_db exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.analytics")
    fn = getattr(mod, "find_archive_db", None)
    assert fn is not None, "'find_archive_db' not found in kindex.analytics"
    assert callable(fn)

def test_session_stats_is_callable():
    """Function session_stats exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.analytics")
    fn = getattr(mod, "session_stats", None)
    assert fn is not None, "'session_stats' not found in kindex.analytics"
    assert callable(fn)

def test_activity_heatmap_is_callable():
    """Function activity_heatmap exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.analytics")
    fn = getattr(mod, "activity_heatmap", None)
    assert fn is not None, "'activity_heatmap' not found in kindex.analytics"
    assert callable(fn)
