"""Smoke tests for src/kindex/hooks.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_hooks():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.hooks")
    assert mod is not None

def test_prime_context_is_callable():
    """Function prime_context exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.hooks")
    fn = getattr(mod, "prime_context", None)
    assert fn is not None, "'prime_context' not found in kindex.hooks"
    assert callable(fn)

def test_capture_session_end_is_callable():
    """Function capture_session_end exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.hooks")
    fn = getattr(mod, "capture_session_end", None)
    assert fn is not None, "'capture_session_end' not found in kindex.hooks"
    assert callable(fn)

def test_write_inbox_item_is_callable():
    """Function write_inbox_item exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.hooks")
    fn = getattr(mod, "write_inbox_item", None)
    assert fn is not None, "'write_inbox_item' not found in kindex.hooks"
    assert callable(fn)

def test_generate_session_directive_is_callable():
    """Function generate_session_directive exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.hooks")
    fn = getattr(mod, "generate_session_directive", None)
    assert fn is not None, "'generate_session_directive' not found in kindex.hooks"
    assert callable(fn)
