"""Smoke tests for src/kindex/llm.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_llm():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.llm")
    assert mod is not None

def test_get_client_is_callable():
    """Function get_client exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.llm")
    fn = getattr(mod, "get_client", None)
    assert fn is not None, "'get_client' not found in kindex.llm"
    assert callable(fn)

def test_calculate_cost_is_callable():
    """Function calculate_cost exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.llm")
    fn = getattr(mod, "calculate_cost", None)
    assert fn is not None, "'calculate_cost' not found in kindex.llm"
    assert callable(fn)

def test_classify_for_graph_is_callable():
    """Function classify_for_graph exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.llm")
    fn = getattr(mod, "classify_for_graph", None)
    assert fn is not None, "'classify_for_graph' not found in kindex.llm"
    assert callable(fn)

def test_smart_search_is_callable():
    """Function smart_search exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.llm")
    fn = getattr(mod, "smart_search", None)
    assert fn is not None, "'smart_search' not found in kindex.llm"
    assert callable(fn)
