"""Smoke tests for src/kindex/config.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_config():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.config")
    assert mod is not None

def test_load_config_is_callable():
    """Function load_config exists and is callable."""
    import importlib
    mod = importlib.import_module("kindex.config")
    fn = getattr(mod, "load_config", None)
    assert fn is not None, "'load_config' not found in kindex.config"
    assert callable(fn)
