"""Smoke tests for src/kindex/models.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_models():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.models")
    assert mod is not None
