"""Smoke tests for src/kindex/adapters/sessions.py (auto-generated by pact adopt)."""

import pytest

def test_import_kindex_adapters_sessions():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("kindex.adapters.sessions")
    assert mod is not None
